<?php
namespace ElementaryAddons;


class EAFREE_Widget_Loader{

  private static $_instance = null;

  public static function instance()
  {
    if (is_null(self::$_instance)) {
      self::$_instance = new self();
    }
    return self::$_instance;
  }

  private function get_settings(){
    $option = get_option( 'elementarty_addons_settings' );
    $decoded = ( $option !== false && $option !== '' ) ? json_decode( stripslashes( $option ), true ) : [];

    return $decoded;
  }

  private function include_widgets_files(){


    $widgets = array(
      'lottie', 'dotlottie', 'vertical_accordion', 'simple_menu', 'dynamic_button',
      'nested_gallery'
    );
    $settings = $this->get_settings();
    for ( $i = 0; $i < count( $widgets ); $i++ ) {
      if( ( isset( $settings['enable_' . $widgets[$i]] ) && $settings['enable_' . $widgets[$i]] === 'yes' ) || !isset( $settings['enable_' . $widgets[$i]] ) ){
        require_once( __DIR__ . '/widgets/' . $widgets[$i] . '.php' );
      }
    }

  }

  public function register_widgets(){

    $settings = $this->get_settings();
    $this->include_widgets_files();

    if( ( isset( $settings['enable_lottie'] ) && $settings['enable_lottie'] === 'yes' ) || !isset( $settings['enable_lottie'] ) ){
      \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\EAFREE_Lottie());
    }

    if( ( isset( $settings['enable_dotlottie'] ) && $settings['enable_dotlottie'] === 'yes' ) || !isset( $settings['enable_dotlottie'] ) ){
      \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\EAFREE_DotLottie());
    }

    if( ( isset( $settings['enable_vertical_accordion'] ) && $settings['enable_vertical_accordion'] === 'yes' ) || !isset( $settings['enable_vertical_accordion'] ) ){
      \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\EAFREE_Vertical_Accordion());
    }

    if( ( isset( $settings['enable_simple_menu'] ) && $settings['enable_simple_menu'] === 'yes' ) || !isset( $settings['enable_simple_menu'] ) ){
      \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\EAFREE_Simple_Menu());
    }

    if( ( isset( $settings['enable_dynamic_button'] ) && $settings['enable_dynamic_button'] === 'yes' ) || !isset( $settings['enable_dynamic_button'] ) ){
      \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\EAFREE_Dynamic_Button());
    }

    if( ( isset( $settings['enable_nested_gallery'] ) && $settings['enable_nested_gallery'] === 'yes' ) || !isset( $settings['enable_nested_gallery'] ) ){
      \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\EAFREE_Nested_Gallery());
    }

  }

  public function __construct(){
    add_action( 'elementor/widgets/widgets_registered', [$this, 'register_widgets'], 99 );
  }

  public function require_extensions(){
    // require_once( __DIR__ . '/widgets/module-base.php' );
    $extensions = array(
      'section_clip_path'
    );
    $settings = $this->get_settings();
    for ( $i = 0; $i < count( $extensions ); $i++ ) {
      if( ( isset( $settings['enable_' . $extensions[$i]] ) && $settings['enable_' . $extensions[$i]] === 'yes' ) || !isset( $settings['enable_' . $extensions[$i]] ) ){
        require_once(__DIR__ . '/widgets/' . $extensions[$i] . '.php');
      }
    }
  }
}


// Instantiate Plugin Class
$ext = new EAFREE_Widget_Loader();
$ext->require_extensions();
EAFREE_Widget_Loader::instance();
