<?php
/**
* Elementary Addons
*
* @package ElementaryAddons
*
* Plugin Name: Elementary Addons
* Description: Elementary Addons and Extensions for Elementor
* Plugin URI:  https://elementary-addons.com
* Version:     1.7.0
* Requires:		 5.9
* Tested:			 6.2.2
* Author:      BRAFT
* Author URI:  https://braft.pl
* Text Domain: elementary-addons
* Domain Path: /languages
* License: GPLv3
* License URI: https://www.gnu.org/licenses/gpl-3.0.html
*/

defined('ABSPATH') or die();

define( 'ELEMENTARY_ADDONS_FREE_PLUGIN_VERSION', '1.7.0' );
define( 'ELEMENTARY_ADDONS_FREE', __FILE__ );
define( 'EAFREE_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
define( 'EAFREE_PLUGIN_DIR_URL', plugin_dir_url( __FILE__ ) );

require_once( EAFREE_PLUGIN_DIR . 'inc/ajax/get_settings.php' );
require plugin_dir_path( ELEMENTARY_ADDONS_FREE ) . 'class-elementary-addons-init.php';
require_once( __DIR__ . '/inc/inline_js.php' );

// Utilities
require_once( __DIR__ . '/utils/dynamic_tag.php' );
require_once( __DIR__ . '/utils/controls_groups.php' );


function elementary_addons_load_textdomain() {
	load_plugin_textdomain( 'elementary-addons', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
}
add_action( 'plugins_loaded', 'elementary_addons_load_textdomain' );



add_action('elementor/editor/after_enqueue_scripts', function() {
	$dir = plugin_dir_url(__FILE__);
	wp_enqueue_script('eafree-elementor-js-override', $dir . 'assets/js/elementor-editor.js', array(), filemtime( plugin_dir_path( __FILE__ ) . 'assets/js/elementor-editor.js' ), true );
	wp_enqueue_style('eafree-elementor-css-override', $dir . 'assets/css/elementor-editor.css', array(), filemtime( plugin_dir_path( __FILE__ ) . 'assets/css/elementor-editor.css' ), 'all' );
});


function elementary_addons_swap_plugin_icon(){
	?>
	<script type="text/javascript">
	jQuery(document).ready(function($){
		$('form.upgrade .plugin-title strong').each(function(){
			var title = $(this).text();
			if(title.includes("Elementary Addons")){
				var def_icon = $(this).parent().find('span.dashicons').replaceWith('<img src="<?php echo plugin_dir_url( __FILE__ ) . 'assets/images/icon-256x256.png' ?>" alt="">')
			}
		});
	});
	</script>
	<?php
}
add_action( 'admin_footer', 'elementary_addons_swap_plugin_icon' );



function elementary_addons_widget_categories( $elements_manager ) {
	$elements_manager->add_category(
		'eafree-widgets',
		[
			'title' => esc_html__( 'Elementary Addons', 'elementary-addons' ),
			'icon' => 'fa fa-plug',
		]
	);
}
add_action( 'elementor/elements/categories_registered', 'elementary_addons_widget_categories' );

//////////////////////////////// SETTINS PAGE //////////////////////////////
add_action( 'admin_menu', 'elementary_addons_admin_menus' );

function elementary_addons_admin_menus() {
	add_submenu_page(
		'options-general.php',
		__( 'Elementary Addons', 'elementary-addons' ),
		__( 'Elementary Addons', 'elementary-addons' ),
		'manage_options',
		'elementary-addons-free-settings',
		'elementary_addons_settings' );
	}

	function elementary_addons_settings() {
		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}
		include ( EAFREE_PLUGIN_DIR . 'inc/settings.php' );
	}

	///////////////////////////////////////////////////////////////////////////

	/////////////////////////////// ADMIN SCRIPTS & STYLES /////////////////////
	function elementary_addons_admin_assets(){
		wp_register_script(
			'elementary-addons-admin-js',
			plugins_url( 'assets/js/eafree_admin.js', __FILE__ ),
			( 'jquery' ),
			filemtime( plugin_dir_path( __FILE__ ) . 'assets/js/eafree_admin.js' ),
			true
		);
		wp_enqueue_script( 'elementary-addons-admin-js' );

		wp_localize_script( 'elementary-addons-admin-js',
		'eafree_object',
		array(
			'ajax_url' => admin_url( 'admin-ajax.php' ),
		)
	);

	wp_register_script(
		'elementary-addons-form-js',
		plugins_url( 'assets/js/jquery_form.js', __FILE__ ),
		array( 'jquery' ),
		filemtime( plugin_dir_path( __FILE__ ) . 'assets/js/jquery_form.js' ),
		true
	);
	wp_enqueue_script( 'elementary-addons-form-js' );

	wp_register_style(
		'elementary-addons-admin-css',
		plugins_url( 'assets/css/eafree_admin.css', __FILE__ ),
		array(),
		filemtime( plugin_dir_path( __FILE__ ) . 'assets/css/eafree_admin.css' )
	);
	wp_enqueue_style('elementary-addons-admin-css');

}
add_action( 'admin_enqueue_scripts', 'elementary_addons_admin_assets' );
///////////////////////////////////////////////////////////////////////////

/////////////////////////////// FRONTEND SCRIPTS & STYLES /////////////////////
function elementary_addons_enqueue_lottie(){
	wp_enqueue_script(
		'lottie-files',
		plugins_url( 'assets/js/lottie-player.js', __FILE__ ),
		array('jquery'),
		'1.0.0',
		true
	);
}
function elementary_addons_enqueue_dotlottie(){
	wp_enqueue_script(
		'dotlottie-files',
		plugins_url( 'assets/js/dotlottie-player.js', __FILE__ ),
		array('jquery'),
		'1.0.0',
		true
	);
}
function elementary_addons_frontend_assets(){
	global $wpdb;
	$post_id = get_queried_object_id();
	$sql = "SELECT meta_value FROM $wpdb->postmeta
	WHERE meta_key='_elementor_data'  AND post_id=$post_id";

	$settings = $wpdb->get_results( $sql );

	if( $post_id === 0 || is_user_logged_in() ){
		elementary_addons_enqueue_lottie();
		elementary_addons_enqueue_dotlottie();
	}
	else{
		foreach ( $settings as $key => $sett ){
			if( str_contains( $sett->meta_value, '"widgetType":"eafree_lottie"' ) ){
				elementary_addons_enqueue_lottie();
				break;
			}
		}
		foreach ( $settings as $key => $sett ){
			if( str_contains( $sett->meta_value, '"widgetType":"eafree_dotlottie"' ) ){
				elementary_addons_enqueue_dotlottie();
				break;
			}
		}
	}


	if( isset( $settings['enable_internal_js'] ) && $settings['enable_internal_js'] !== 'yes' ){
		wp_register_script(
			'elementary-addons-frontend-js',
			plugins_url( 'assets/js/ea_frontend.js', __FILE__ ),
			array( 'jquery', 'jquery-ui-datepicker' ),
			filemtime( plugin_dir_path( __FILE__ ) . 'assets/js/ea_frontend.js' ),
			true
		);
		wp_enqueue_script( 'elementary-addons-frontend-js' );

		wp_localize_script(
			'elementary-addons-frontend-js',
			'ea_frontend_object',
			array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'nonce' => wp_create_nonce('ajax-nonce'),
			)
		);
	}
	if( isset( $settings['enable_internal_css'] ) && $settings['enable_internal_css'] !== 'yes' ){
		wp_register_style(
			'elementary-addons-frontend-css',
			plugins_url( 'assets/css/ea_frontend.css', __FILE__ ),
			array(),
			filemtime( plugin_dir_path( __FILE__ ) . 'assets/css/ea_frontend.css' )
		);
		wp_enqueue_style('elementary-addons-frontend-css');
	}

}
add_action( 'wp_enqueue_scripts', 'elementary_addons_frontend_assets' );
///////////////////////////////////////////////////////////////////////////



function elementary_addons_manage_settings() {
	require_once( EAFREE_PLUGIN_DIR . 'inc/ajax/save_settings.php' );
}
add_action( 'wp_ajax_elementary_addons_manage_settings', 'elementary_addons_manage_settings' );

$GLOBALS['elementary_addons_lottie_count'] = 0;
$GLOBALS['elementary_addons_dotlottie_count'] = 0;
$GLOBALS['elementary_addons_vertical_accordion_count'] = 0;
$GLOBALS['elementary_addons_simple_menu_count'] = 0;
$GLOBALS['elementary_addons_dynamic_button_count'] = 0;
$GLOBALS['elementary_addons_nested_gallery_count'] = 0;


function elementary_addons_admin_js_css() {

	if( ! isset( $settings['enable_internal_css'] ) || $settings['enable_internal_css'] === 'yes' ){
		require_once( __DIR__ . '/inc/inline_css.php' );
	}
	?>
	<?php if( ! \Elementor\Plugin::$instance->editor->is_edit_mode() && ( ! isset( $settings['enable_internal_js'] ) || $settings['enable_internal_js'] === 'yes' ) ): ?>

		<script type="text/javascript" class="eafree_not_logged_in_js">

		jQuery(document).ready(function($){
			<?php
			///////////////////// widgets scripts /////////////////////////////////
			$js = new ElementaryAddons\EAFREE_Inline_JS();
			if(
				$GLOBALS['elementary_addons_lottie_count'] > 0
			){
				$js->elementary_addons_is_in_viewport();
			}

			if( $GLOBALS['elementary_addons_lottie_count'] > 0 ){
				$js->elementary_addons_lottie_js( '.eafree_lottie' );
			}
			if( $GLOBALS['elementary_addons_dotlottie_count'] > 0 ){
				$js->elementary_addons_dotlottie_js( '.eafree_dotlottie' );
			}
			if( $GLOBALS['elementary_addons_vertical_accordion_count'] > 0 ){
				$js->elementary_addons_vertical_accordion_js( '.eafree_vertical_accordion' );
			}
			if( $GLOBALS['elementary_addons_simple_menu_count'] > 0 ){
				$js->elementary_addons_simple_menu_js( '.eafree_simple_menu_nav' );
			}
			if( $GLOBALS['elementary_addons_dynamic_button_count'] > 0 ){
				$js->elementary_addons_dynamic_button_js( '.eafree_dynamic_button' );
			}
			if( $GLOBALS['elementary_addons_nested_gallery_count'] > 0 ){
				$js->elementary_addons_nested_gallery_js( '.eafree_nested_gallery' );
			}
			?>
		}); // end doc ready
		</script>
	<?php endif; ?>
	<?php
}
add_action('wp_footer', 'elementary_addons_admin_js_css', 99);

function elementary_addons_mime_types( $mime_types ){
	$mime_types['lottie'] = 'application/zip+lottie';
	return $mime_types;
}
add_action( 'upload_mimes', 'elementary_addons_mime_types');
///////////////// BBPRESS SINGLE FORUM CONTENT AJAX /////////////////////////////
// function elementary_addons_bbp_single_forum_content_ajax() {
// 	require_once( BEA_PLUGIN_DIR . 'inc/ajax/wc_products_filter_text_field_ajax.php' );
// 	echo do_shortcode( '[bbp-single-forum id=2320]' );
// 	echo 'test';
// 	wp_die();
// }
// add_action('wp_ajax_nopriv_elementary_addons_bbp_single_forum_content_ajax', 'elementary_addons_bbp_single_forum_content_ajax');
// add_action( 'wp_ajax_elementary_addons_bbp_single_forum_content_ajax', 'elementary_addons_bbp_single_forum_content_ajax' );
