<?php

namespace ElementaryAddons\Widgets;

use ElementaryAddons\Utils\EAFREE_Controls_Groups;
use ElementaryAddons\Utils\EAFREE_Dynamic_Tag;
use ElementaryAddons\EAFREE_Inline_JS;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Core\DynamicTags\Tag;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Icons_Manager;

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class eafree_dynamic_button extends Widget_Base{

  public function get_name(){
    return 'eafree_dynamic_button';
  }

  public function get_title(){
    return esc_html__('Dynamic Button', 'elementary-addons');
  }

  public function get_icon(){
    return 'eafree-icon eafree-icon-dynamic-button';
  }

  public function get_categories(){
    return ['eafree-widgets'];
  }

  public function get_group() {
    return ['posts'];
  }

  protected function register_controls(){

    ///////////////////////////// GENERAL //////////////////////////////////
    $this->start_controls_section(
      'eafree_dynamic_button_settings_general',
      [
        'label' => 'General',
      ]
    );

    $this->add_responsive_control(
      'eafree_dynamic_button_align',
      [
        'label' => esc_html__( 'Alignment', 'elementary-addons' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          'left'    => [
            'title' => esc_html__( 'Left', 'elementary-addons' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' => esc_html__( 'Center', 'elementary-addons' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' => esc_html__( 'Right', 'elementary-addons' ),
            'icon' => 'eicon-text-align-right',
          ],
        ],
        'default' => 'center',
        'selectors' => [
          '{{WRAPPER}} .eafree_dynamic_button' => 'text-align:{{VALUE}};',
        ],
      ]
    );

    $this->end_controls_section();

    ///////////////////////////// BUTTON TEXT //////////////////////////////////
    $this->start_controls_section(
      'eafree_dynamic_button_settings_text',
      [
        'label' => 'Button Text',
      ]
    );

    $this->add_control(
      'eafree_dynamic_button_text_is_icon',
      [
        'label' => esc_html__( 'Show Icon', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Show', 'elementary-addons' ),
        'label_off' => esc_html__( 'Hide', 'elementary-addons' ),
        'return_value' => 'yes',
        'default' => '',
      ]
    );

    $this->add_control(
      'eafree_dynamic_button_text_icon',
      [
        'label' => esc_html__( 'Icon', 'elementary-addons' ),
        'type' => Controls_Manager::ICONS,
        'skin' => 'inline',
        'label_block' => false,
        'default' => [
          'value' => 'fas fa-icons',
          'library' => 'fa-solid',
        ],
        'condition' => [ 'eafree_dynamic_button_text_is_icon' => 'yes' ],
      ]
    );

    $this->add_control(
      'eafree_dynamic_button_text_is_dynamic',
      [
        'label' => esc_html__( 'Dynamic Title', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementary-addons' ),
        'label_off' => esc_html__( 'No', 'elementary-addons' ),
        'return_value' => 'yes',
        'default' => '',
      ]
    );

    $this->add_control(
      'eafree_dynamic_button_text_title',
      [
        'label' => esc_html__( 'Separator', 'elementary-addons' ),
        'type' => Controls_Manager::TEXT,
        'placeholder' => esc_html__( 'Some Button Title', 'elementary-addons' ),
        'default' => esc_html__( 'Some Button Title', 'elementary-addons' ),
        'condition' => [ 'eafree_dynamic_button_text_is_dynamic' => '' ],
      ]
    );

    $repeater = new \Elementor\Repeater();

    $get_dyn_tag = new EAFREE_Dynamic_Tag();
    $get_dyn_tag->get_dynamic_tag_controls( $repeater, 'eafree_dynamic_button_text', 'text', [] );

    $this->add_control(
      'eafree_dynamic_button_text_items',
      [
        'label' => esc_html__( 'Button Text Items', 'elementary-addons' ),
        'type' => Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        // 'title_field' => '{{{ braft_dynamic_tags_item_dynamic_tag_type.replace(/_/g, " ").toUpperCase() }}}',
        'condition' => [ 'eafree_dynamic_button_text_is_dynamic' => 'yes' ],
      ]
    );

    $this->end_controls_section();

    ///////////////////////////// BUTTON LINK //////////////////////////////////
    $this->start_controls_section(
      'eafree_dynamic_button_settings_link',
      [
        'label' => 'Button Link',
      ]
    );

    $this->add_control(
      'eafree_dynamic_button_link_new_window',
      [
        'label' => esc_html__( 'Open In New Window', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementary-addons' ),
        'label_off' => esc_html__( 'No', 'elementary-addons' ),
        'return_value' => 'yes',
        'default' => '',
      ]
    );

    $this->add_control(
      'eafree_dynamic_button_link_is_dynamic',
      [
        'label' => esc_html__( 'Dynamic Link', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementary-addons' ),
        'label_off' => esc_html__( 'No', 'elementary-addons' ),
        'return_value' => 'yes',
        'default' => '',
      ]
    );

    $this->add_control(
      'eafree_dynamic_button_link_content',
      [
        'label' => esc_html__( 'Separator', 'elementary-addons' ),
        'type' => Controls_Manager::TEXT,
        'placeholder' => esc_html__( 'https://example.com', 'elementary-addons' ),
        'condition' => [ 'eafree_dynamic_button_link_is_dynamic' => '' ],
      ]
    );

    $repeater2 = new \Elementor\Repeater();

    $get_dyn_tag2 = new EAFREE_Dynamic_Tag();
    $get_dyn_tag2->get_dynamic_tag_controls( $repeater2, 'eafree_dynamic_button_link', 'text', [] );

    $this->add_control(
      'eafree_dynamic_button_link_items',
      [
        'label' => esc_html__( 'Button Link Items', 'elementary-addons' ),
        'type' => Controls_Manager::REPEATER,
        'fields' => $repeater2->get_controls(),
        // 'title_field' => '{{{ braft_dynamic_tags_item_dynamic_tag_type.replace(/_/g, " ").toUpperCase() }}}',
        'condition' => [ 'eafree_dynamic_button_link_is_dynamic' => 'yes' ],
      ]
    );

    $this->end_controls_section();

    ////////////////////////////// BUTTON STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_dynamic_button_style',
      [
        'label' => 'Button',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    EAFREE_Controls_Groups::get_button_style_controls(
      $this,
      'eafree_dynamic_button',
      array(
        '{{WRAPPER}} .eafree_dynamic_button a',
      ),
      array(

      ),
    );

    $this->end_controls_section();

  }//end register controls



  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();
    $button_text = '';
    $button_text_items = $settings['eafree_dynamic_button_text_items'];
    if( $settings['eafree_dynamic_button_text_is_dynamic'] === 'yes' ){
      if( ! empty( $button_text_items ) ){
        for ( $i = 0; $i < count( $button_text_items ); $i++ ) {
          $get_dyn_tag = new EAFREE_Dynamic_Tag();
          $button_text .= $get_dyn_tag->get_dynamic_tag( $settings, $button_text_items[$i], 'eafree_dynamic_button_text', 'text' );
        }
      }
    }
    else{
      $button_text .= $settings['eafree_dynamic_button_text_title'];
    }

    $button_link = '';
    $button_link_items = $settings['eafree_dynamic_button_link_items'];
    if( $settings['eafree_dynamic_button_link_is_dynamic'] === 'yes' ){
      if( ! empty( $button_link_items ) ){
        for ( $i = 0; $i < count( $button_link_items ); $i++ ) {
          $get_dyn_tag2 = new EAFREE_Dynamic_Tag();
          $button_link .= $get_dyn_tag2->get_dynamic_tag( $settings, $button_link_items[$i], 'eafree_dynamic_button_link', 'text' );
        }
      }
    }
    else{
      $button_link .= $settings['eafree_dynamic_button_link_content'];
    }

    $target = ( $settings['eafree_dynamic_button_link_new_window'] === 'yes' ) ? 'target="_blank"' : '';
    ?>
    <div class="eafree_dynamic_button eafree_dynamic_button_<?php echo esc_attr( $id ); ?>">
      <a
      href="<?php echo esc_url( $button_link ); ?>"
      class="elementor-button"
      <?php echo esc_attr( $target ); ?>
      >
        <span>
          <?php
          if( $settings['eafree_dynamic_button_text_is_icon'] === 'yes' ){
            Icons_Manager::render_icon( $settings['eafree_dynamic_button_text_icon'], [ 'aria-hidden' => 'true' ] );
          }
          ?>
        </span>
        <span>
          <?php
          echo esc_html( $button_text );
          ?>
        </span>

      </a>
    </div>
    <?php if( \Elementor\Plugin::$instance->editor->is_edit_mode() ): ?>
      <script type="text/javascript">

      jQuery(document).ready(function($){
        <?php
        EAFREE_Inline_JS::elementary_addons_dynamic_button_js( '.eafree_dynamic_button_' . $id );
        ?>
      });

      </script>
    <?php endif; ?>
    <?php
    $GLOBALS['elementary_addons_dynamic_button_count'] += 1;
    // echo '<pre>';
    // var_dump( $button_text_items );
    // echo '</pre>';
  }// end render
}
