<?php

namespace ElementaryAddons\Widgets;

use ElementaryAddons\Utils\EAFREE_Controls_Groups;
use ElementaryAddons\Utils\EAFREE_Dynamic_Tag;
use ElementaryAddons\EAFREE_Inline_JS;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Core\DynamicTags\Tag;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Icons_Manager;

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class EAFREE_Nested_Gallery extends Widget_Base{

  public function get_name(){
    return 'eafree_nested_gallery';
  }

  public function get_title(){
    return esc_html__('Nested Gallery', 'elementary-addons');
  }

  public function get_icon(){
    return 'eafree-icon eafree-icon-nested-gallery'; // eicon-site-logo
  }

  public function get_categories(){
    return ['eafree-widgets'];
  }

  public function get_group() {
    return ['posts'];
  }

  protected function register_controls(){

    $this->start_controls_section(
      'eafree_nested_gallery_settings_general',
      [
        'label' => 'General',
      ]
    );

    $this->add_responsive_control(
      'eafree_nested_gallery_min_img_width',
      [
        'label'   => esc_html__( 'Min Image Width', 'elementary-addons' ),
        'type'    => Controls_Manager::NUMBER,
        // 'default' => 140,
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery ul' => 'display:grid; grid-auto-flow:dense; grid-template-columns:repeat(auto-fit, minmax({{VALUE}}px, 1fr));',
        ],
        'devices' => [ 'desktop', 'tablet', 'mobile' ],
        'desktop_default' => 300,
        'tablet_default' => 300,
        'mobile_default' => 300,
      ]
    );

    $this->add_responsive_control(
      'eafree_nested_gallery_grid_gap',
      [
        'label'   => esc_html__( 'Grid Gap', 'elementary-addons' ),
        'type'    => Controls_Manager::NUMBER,
        // 'default' => 10,
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery ul' => 'grid-gap:{{VALUE}}px;',
        ],
        'devices' => [ 'desktop', 'tablet', 'mobile' ],
        'desktop_default' => 20,
        'tablet_default' => 10,
        'mobile_default' => 10,
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_main_img_size_h',
      [
        'label'   => esc_html__( 'Main Image', 'elementary-addons' ),
        'type' => \Elementor\Controls_Manager::HEADING,
        'separator' => 'before',
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Image_Size::get_type(),
      [
        'name' => 'eafree_nested_gallery_main_img_size',
        'default' => 'large',
        'separator' => 'none',
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_slider_img_size_h',
      [
        'label'   => esc_html__( 'Slider Image', 'elementary-addons' ),
        'type' => \Elementor\Controls_Manager::HEADING,
        'separator' => 'before',
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Image_Size::get_type(),
      [
        'name' => 'eafree_nested_gallery_slider_img_size',
        'default' => 'large',
        'separator' => 'none',
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_lightbox_img_size_h',
      [
        'label'   => esc_html__( 'Lightbox Image', 'elementary-addons' ),
        'type' => \Elementor\Controls_Manager::HEADING,
        'separator' => 'before',
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Image_Size::get_type(),
      [
        'name' => 'eafree_nested_gallery_lightbox_img_size',
        'default' => 'large',
        'separator' => 'none',
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_show_caption',
      [
        'label' => esc_html__( 'Show Caption', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Show', 'elementary-addons' ),
        'label_off' => esc_html__( 'Hide', 'elementary-addons' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->end_controls_section();

    //////////////////////////////// GALLERY ITEMS ////////////////////////////
    $this->start_controls_section(
      'eafree_nested_gallery_items_settings',
      [
        'label' => 'Items',
      ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
      'eafree_nested_gallery_item_main_img',
      [
        'label' => esc_html__( 'Choose Main Image', 'elementary-addons' ),
        'type' => \Elementor\Controls_Manager::MEDIA,
        'default' => [
          'url' => \Elementor\Utils::get_placeholder_image_src(),
        ],
      ]
    );

    $repeater->add_control(
      'eafree_nested_gallery_item_img_cap_source',
      [
        'label' => esc_html__( 'Image Caption Source', 'elementary-addons' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'caption',
        'options' => [
          'alt' => esc_html__( 'Image Alt', 'elementary-addons' ),
          'title' => esc_html__( 'Image Title', 'elementary-addons' ),
          'caption' => esc_html__( 'Image Caption', 'elementary-addons' ),
          'description' => esc_html__( 'Image Description', 'elementary-addons' ),
          'url' => esc_html__( 'Image URL', 'elementary-addons' ),
          'dynamic' => esc_html__( 'Dynamic', 'elementary-addons' ),
          'custom' => esc_html__( 'Custom', 'elementary-addons' ),
        ],
      ]
    );

    $repeater->add_control(
      'eafree_nested_gallery_item_caption_text',
      [
        'label' => esc_html__( 'Caption text', 'elementary-addons' ),
        'type' => Controls_Manager::TEXTAREA,
        'rows' => 3,
        'default' => esc_html__( 'Some image caption', 'elementary-addons' ),
        'condition' => [
          'eafree_nested_gallery_item_img_cap_source' => 'custom',
        ],
      ]
    );

    $get_dyn_tag = new EAFREE_Dynamic_Tag();
    $get_dyn_tag->get_dynamic_tag_controls( $repeater, 'eafree_nes_gal_item_cap_dyn', 'text', [] );

    $repeater->add_control(
      'eafree_nested_gallery_item_subgal',
      [
        'label' => esc_html__( 'Add Nested Images', 'elementary-addons' ),
        'type' => Controls_Manager::GALLERY,
        // 'condition' => [
        // 	'query_selection' => 'manual',
        // ],
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_items_list',
      [
        'label' => __( 'Items', 'elementary-addons' ),
        'type' => Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'eafree_nested_gallery_item_img_cap_source' => 'title',
            'eafree_nested_gallery_item_main_img' => [
              'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
          ],
          [
            'eafree_nested_gallery_item_img_cap_source' => 'title',
            'eafree_nested_gallery_item_main_img' => [
              'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
          ],
          [
            'eafree_nested_gallery_item_img_cap_source' => 'title',
            'eafree_nested_gallery_item_main_img' => [
              'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
          ],

        ],
        // 'title_field' => '{{{ eafree_vertical_accordion_tab_text }}}',
      ]
    );

    $this->end_controls_section();

    ////////////////////////////// CARD STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_nested_gallery_card_style',
      [
        'label' => 'Gallery Card',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );


    EAFREE_Controls_Groups::get_block_style_controls(
      $this,
      'eafree_nested_gallery_card',
      array(
        '{{WRAPPER}} .eafree_nested_gallery > ul > li',
      ),
      array(

      ),
    );

    $this->end_controls_section();

    ////////////////////////////// MAIN IMAGE STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_nested_gallery_main_img_style',
      [
        'label' => 'Main Image',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );


    EAFREE_Controls_Groups::get_block_style_controls(
      $this,
      'eafree_nested_gallery_main_img',
      array(
        '{{WRAPPER}} .eafree_nested_gallery > ul > li img',
      ),
      array(
        'margin'
      ),
    );

    $this->end_controls_section();

    ////////////////////////////// CAPTION STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_nested_gallery_caption_style',
      [
        'label' => 'Caption',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_responsive_control(
      'eafree_nested_gallery_caption_align',
      [
        'label' =>esc_html__( 'Text Alignment', 'braft-elementary-addons' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          'left'    => [
            'title' =>esc_html__( 'Left', 'braft-elementary-addons' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' =>esc_html__( 'Center', 'braft-elementary-addons' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' =>esc_html__( 'Right', 'braft-elementary-addons' ),
            'icon' => 'eicon-text-align-right',
          ],
        ],
        'default' => 'center',
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery > ul > li figcaption' => 'text-align: {{VALUE}};',
        ],
      ]
    );

    EAFREE_Controls_Groups::get_block_style_controls(
      $this,
      'eafree_nested_gallery_caption',
      array(
        '{{WRAPPER}} .eafree_nested_gallery > ul > li figcaption',
      ),
      array(

      ),
    );

    $this->end_controls_section();

    ////////////////////////////// LIGHTBOX STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_nested_gallery_lightbox_style',
      [
        'label' => 'Lightbox',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_control(
      'eafree_nested_gallery_lightbox_color',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox' => 'background: {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    ////////////////////////////// LIGHTBOX CLOSE STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_nested_gallery_lightbox_close_style',
      [
        'label' => 'Lightbox Close Button',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_lightbox_close_icon',
      [
        'label' => esc_html__( 'Close Icon', 'elementary-addons' ),
        'type' => Controls_Manager::ICONS,
        'skin' => 'inline',
        'label_block' => false,
        'default' => [
          'value' => 'fas fa-times',
          'library' => 'fa-solid',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_nested_gallery_lightbox_close_icon_size',
      [
        'label' => esc_html__( 'Icon Size', 'braft-elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
        ],
        'default' => [
          'unit' => 'px',
          'size' => 30,
        ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close i' => 'font-size: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->start_controls_tabs( 'eafree_nes_gal_lghtbox_close_button_styles' );

    $this->start_controls_tab(
      'eafree_nes_gal_lghtbox_close_button_normal',
      [
        'label' => esc_html__( 'Normal', 'elementary-addons' ),
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_close_button_color',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close i' => 'color: {{VALUE}}',
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close svg' => 'fill: {{VALUE}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_close_button_shadow',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .close i',
      ]
    );



    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_close_button_padding',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_close_button_margin',
      [
        'label' => esc_html__( 'Margin', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => 'eafree_nes_gal_lghtbox_close_button_border',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .close',
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_close_button_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_close_button_background',
        'types' => [ 'classic', 'gradient' ],
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .close',
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_close_button_shadow',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .close',
      ]
    );

    $this->end_controls_tab();

    $this->start_controls_tab(
      'eafree_nes_gal_lghtbox_close_button_button_hover',
      [
        'label' => esc_html__( 'Hover', 'elementary-addons' ),
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_close_button_color_hover',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close i:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close svg:hover' => 'fill: {{VALUE}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_close_button_shadow_hover',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .close i:hover',
      ]
    );



    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_close_button_padding_hover',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_close_button_margin_hover',
      [
        'label' => esc_html__( 'Margin', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => 'eafree_nes_gal_lghtbox_close_button_border_hover',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .close:hover',
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_close_button_border_radius_hover',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .close:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_close_button_background_hover',
        'types' => [ 'classic', 'gradient' ],
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .close:hover',
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_close_button_shadow_hover',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .close:hover',
      ]
    );

    $this->end_controls_tab();
    $this->end_controls_tabs();

    $this->end_controls_section();

    ////////////////////////////// LIGHTBOX PREV STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_nested_gallery_lightbox_prev_style',
      [
        'label' => 'Lightbox Prev Button',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_lightbox_prev_icon',
      [
        'label' => esc_html__( 'Prev Icon', 'elementary-addons' ),
        'type' => Controls_Manager::ICONS,
        'skin' => 'inline',
        'label_block' => false,
        'default' => [
          'value' => 'fas fa-chevron-left',
          'library' => 'fa-solid',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_nested_gallery_lightbox_prev_icon_size',
      [
        'label' => esc_html__( 'Icon Size', 'braft-elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
        ],
        'default' => [
          'unit' => 'px',
          'size' => 30,
        ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev i' => 'font-size: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_lightbox_prev_icon',
      [
        'label' => esc_html__( 'Prev Icon', 'elementary-addons' ),
        'type' => Controls_Manager::ICONS,
        'skin' => 'inline',
        'label_block' => false,
        'default' => [
          'value' => 'fas fa-times',
          'library' => 'fa-solid',
        ],
      ]
    );

    $this->start_controls_tabs( 'eafree_nes_gal_lghtbox_prev_button_styles' );

    $this->start_controls_tab(
      'eafree_nes_gal_lghtbox_prev_button_normal',
      [
        'label' => esc_html__( 'Normal', 'elementary-addons' ),
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_prev_button_color',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev i' => 'color: {{VALUE}}',
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev svg' => 'fill: {{VALUE}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_prev_button_shadow',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev i',
      ]
    );



    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_prev_button_padding',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_prev_button_margin',
      [
        'label' => esc_html__( 'Margin', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => 'eafree_nes_gal_lghtbox_prev_button_border',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev',
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_prev_button_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_prev_button_background',
        'types' => [ 'classic', 'gradient' ],
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev',
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_prev_button_shadow',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev',
      ]
    );

    $this->end_controls_tab();

    $this->start_controls_tab(
      'eafree_nes_gal_lghtbox_prev_button_button_hover',
      [
        'label' => esc_html__( 'Hover', 'elementary-addons' ),
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_prev_button_color_hover',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev i:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev svg:hover' => 'fill: {{VALUE}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_prev_button_shadow_hover',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev i:hover',
      ]
    );



    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_prev_button_padding_hover',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_prev_button_margin_hover',
      [
        'label' => esc_html__( 'Margin', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => 'eafree_nes_gal_lghtbox_prev_button_border_hover',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev:hover',
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_prev_button_border_radius_hover',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_prev_button_background_hover',
        'types' => [ 'classic', 'gradient' ],
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev:hover',
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_prev_button_shadow_hover',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .prev:hover',
      ]
    );

    $this->end_controls_tab();
    $this->end_controls_tabs();

    $this->end_controls_section();

    ////////////////////////////// LIGHTBOX NEXT STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_nested_gallery_lightbox_next_style',
      [
        'label' => 'Lightbox Next Button',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_lightbox_next_icon',
      [
        'label' => esc_html__( 'Next Icon', 'elementary-addons' ),
        'type' => Controls_Manager::ICONS,
        'skin' => 'inline',
        'label_block' => false,
        'default' => [
          'value' => 'fas fa-chevron-right',
          'library' => 'fa-solid',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_nested_gallery_lightbox_next_icon_size',
      [
        'label' => esc_html__( 'Icon Size', 'braft-elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
        ],
        'default' => [
          'unit' => 'px',
          'size' => 30,
        ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next i' => 'font-size: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'eafree_nested_gallery_lightbox_next_icon',
      [
        'label' => esc_html__( 'Next Icon', 'elementary-addons' ),
        'type' => Controls_Manager::ICONS,
        'skin' => 'inline',
        'label_block' => false,
        'default' => [
          'value' => 'fas fa-times',
          'library' => 'fa-solid',
        ],
      ]
    );

    $this->start_controls_tabs( 'eafree_nes_gal_lghtbox_next_button_styles' );

    $this->start_controls_tab(
      'eafree_nes_gal_lghtbox_next_button_normal',
      [
        'label' => esc_html__( 'Normal', 'elementary-addons' ),
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_next_button_color',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next i' => 'color: {{VALUE}}',
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next svg' => 'fill: {{VALUE}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_next_button_shadow',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .next i',
      ]
    );



    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_next_button_padding',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_next_button_margin',
      [
        'label' => esc_html__( 'Margin', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => 'eafree_nes_gal_lghtbox_next_button_border',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .next',
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_next_button_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_next_button_background',
        'types' => [ 'classic', 'gradient' ],
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .next',
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_next_button_shadow',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .next',
      ]
    );

    $this->end_controls_tab();

    $this->start_controls_tab(
      'eafree_nes_gal_lghtbox_next_button_button_hover',
      [
        'label' => esc_html__( 'Hover', 'elementary-addons' ),
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_next_button_color_hover',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next i:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next svg:hover' => 'fill: {{VALUE}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_next_button_shadow_hover',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .next i:hover',
      ]
    );



    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_next_button_padding_hover',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_nes_gal_lghtbox_next_button_margin_hover',
      [
        'label' => esc_html__( 'Margin', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => 'eafree_nes_gal_lghtbox_next_button_border_hover',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .next:hover',
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_control(
      'eafree_nes_gal_lghtbox_next_button_border_radius_hover',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .eafree_nested_gallery_lightbox .next:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_next_button_background_hover',
        'types' => [ 'classic', 'gradient' ],
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .next:hover',
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'eafree_nes_gal_lghtbox_next_button_shadow_hover',
        'selector' => '{{WRAPPER}} .eafree_nested_gallery_lightbox .next:hover',
      ]
    );

    $this->end_controls_tab();
    $this->end_controls_tabs();

    $this->end_controls_section();

  }//end register controls



  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();
    ?>
    <div class="eafree_nested_gallery eafree_nested_gallery_<?php echo esc_attr( $id ); ?>">
      <?php
      if ( $settings['eafree_nested_gallery_items_list'] ):
        ?>
        <ul>
          <?php
          foreach (  $settings['eafree_nested_gallery_items_list'] as $item ):
            $att_id = $item['eafree_nested_gallery_item_main_img']['id'];
            $subgal_src = [];
            foreach ( $item['eafree_nested_gallery_item_subgal'] as $image ) {
              array_push( $subgal_src, $image['url'] );
            }
            ?>
            <li
            class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?>"
            data-subgal_src="<?php echo esc_attr( json_encode( $subgal_src ) ); ?>"
            >
            <figure>
              <?php
              $att_image = wp_get_attachment_image( $att_id, $settings['eafree_nested_gallery_main_img_size_size'] );
              $placeholder_src = \Elementor\Utils::get_placeholder_image_src();
              $image_final = ( $att_image !== '' ) ? $att_image : '<img src="' . $placeholder_src . '"/>';
              echo $image_final;
              ?>
              <?php if( $settings['eafree_nested_gallery_show_caption'] === 'yes' ): ?>
                <figcaption>
                  <?php
                  if( isset( $att_id ) && !empty( $att_id ) ){
                    switch ( $item['eafree_nested_gallery_item_img_cap_source'] ) {
                      case 'alt':
                      echo get_post_meta( $att_id, '_wp_attachment_image_alt', true );
                      break;
                      case 'title':
                      echo get_the_title( $att_id );
                      break;
                      case 'caption':
                      echo get_the_excerpt( $att_id );
                      break;
                      case 'description':
                      echo get_the_content( $att_id );
                      break;
                      case 'url':
                      echo wp_get_attachment_url( $att_id );
                      break;
                      case 'custom':
                      echo esc_html( $item['eafree_nested_gallery_item_caption_text'] );
                      break;
                      case 'dynamic':
                      $items = $settings['eafree_dynamic_button_text_items'];
                      $get_dyn_tag = new EAFREE_Dynamic_Tag();
                      echo $get_dyn_tag->get_dynamic_tag( $settings, $item, 'eafree_nes_gal_item_cap_dyn', 'text' );

                      default:
                      // code...
                      break;
                    }
                  }
                  else{
                    echo '...';
                  }
                  ?>
                </figcaption>
              <?php endif; ?>
            </figure>
          </li>
          <?php
        endforeach;
        ?>
      </ul>
      <?php
    endif;
    ?>
    <div class="eafree_nested_gallery_lightbox">
      <div class="prev">
        <?php
        Icons_Manager::render_icon( $settings['eafree_nested_gallery_lightbox_prev_icon'], [ 'aria-hidden' => 'true' ] );
        ?>
      </div>
      <div class="next">
        <?php
        Icons_Manager::render_icon( $settings['eafree_nested_gallery_lightbox_next_icon'], [ 'aria-hidden' => 'true' ] );
        ?>
      </div>
      <div class="close">
        <?php
        Icons_Manager::render_icon( $settings['eafree_nested_gallery_lightbox_close_icon'], [ 'aria-hidden' => 'true' ] );
        ?>
      </div>
    </div>
  </div>
  <?php if( \Elementor\Plugin::$instance->editor->is_edit_mode() ): ?>
    <script type="text/javascript">

    jQuery(document).ready(function($){
      <?php
      EAFREE_Inline_JS::elementary_addons_nested_gallery_js( '.eafree_nested_gallery_' . $id );
      ?>

    }); // end doc ready

    </script>
    <?php endif; ?>
    <?php
    $GLOBALS['elementary_addons_nested_gallery_count'] += 1;
  }// end render
}
