<?php

namespace ElementaryAddons\Widgets;

use ElementaryAddons\Utils\EAFREE_Controls_Groups;
use ElementaryAddons\EAFREE_Inline_JS;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Core\DynamicTags\Tag;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Icons_Manager;

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class EAFREE_Simple_Menu extends Widget_Base{

  public function get_name(){
    return 'eafree_simple_menu';
  }

  public function get_title(){
    return esc_html__('Simple Menu', 'elementary-addons');
  }

  public function get_icon(){
    return 'eafree-icon eafree-icon-simple-menu'; // eicon-site-logo
  }

  public function get_categories(){
    return ['eafree-widgets'];
  }

  public function get_group() {
    return ['posts'];
  }

  protected function register_controls(){

    $this->start_controls_section(
      'eafree_simple_menu_settings_general',
      [
        'label' => 'General',
      ]
    );

    $menus = get_terms('nav_menu');
    $options = [];
    for ( $i = 0; $i < count( $menus ); $i++ ) {
      $options[$menus[$i]->slug] = $menus[$i]->name;
    }

    $this->add_control(
      'eafree_simple_menu_choose_menu',
      [
        'label' =>esc_html__( 'Choose Menu', 'elementary-addons' ),
        'type' => Controls_Manager::SELECT,
        'options' => $options,
        // 'default' => 'center',
        // 'selectors' => [
        //   '{{WRAPPER}} .post_navigation' => 'text-align: {{VALUE}};',
        // ],
      ]
    );

    $this->add_control(
      'eafree_simple_menu_orientation',
      [
        'label' => esc_html__( 'Menu Orientation', 'elementary-addons' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'auto',
        'options' => [
          'inline-block' => esc_html__( 'Horizontal', 'elementary-addons' ),
          'auto' => esc_html__( 'Vertical', 'elementary-addons' ),
        ],
        'selectors' => [
          '{{WRAPPER}} .eafree_simple_menu_nav ul li' => 'display: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'eafree_simple_menu_separator',
      [
        'label' => esc_html__( 'Separator', 'elementary-addons' ),
        'type' => Controls_Manager::TEXT,
        'placeholder' => esc_html__( 'text or code,eg.:\2721', 'elementary-addons' ),
        'selectors' => [
          '{{WRAPPER}} .eafree_simple_menu_nav ul li:not(:last-child)::after' => 'content: "{{VALUE}}";',
        ],
      ]
    );

    $this->end_controls_section();

    ////////////////////////////// GENERAL STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_simple_menu_general_style',
      [
        'label' => 'General',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    EAFREE_Controls_Groups::get_block_style_controls(
      $this,
      'eafree_simple_menu_list',
      array(
        '{{WRAPPER}} .eafree_simple_menu_nav ul',
      ),
      array(

      ),
    );

    $this->end_controls_section();

    ////////////////////////////// MENU LINK STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_simple_menu_link_style',
      [
        'label' => 'Menu Link',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );


    EAFREE_Controls_Groups::get_button3_style_controls(
      $this,
      'eafree_simple_menu_link_list',
      array(
        '{{WRAPPER}} .eafree_simple_menu_nav ul li',
      ),
      array(
        '{{WRAPPER}} .eafree_simple_menu_nav ul li a',
      ),
      array(
        '{{WRAPPER}} .eafree_simple_menu_nav ul li a:hover',
      ),
    );

    $this->end_controls_section();

    ////////////////////////////// SEPARATOR STYLE //////////////////////////////////////
    $this->start_controls_section(
      'eafree_simple_menu_separator_style',
      [
        'label' => 'Separator',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_responsive_control(
      'eafree_simple_menu_separator_size',
      [
        'label' => esc_html__( 'Top Margin', 'elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 1,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 18,
          'unit' => 'px',
        ],
        'selectors' => [
          '{{WRAPPER}} .eafree_simple_menu_nav ul li:not(:last-child)::after' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'eafree_simple_menu_separator_color',
      [
        'label'  => esc_html__( 'Icon Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '#888888',
        'selectors' => [
          '{{WRAPPER}} .eafree_simple_menu_nav ul li:not(:last-child)::after' => 'color: {{VALUE}}',
        ],
      ]
    );

    EAFREE_Controls_Groups::get_block_style_controls(
      $this,
      'eafree_simple_menu_separator',
      array(
        '{{WRAPPER}} .eafree_simple_menu_nav ul li:not(:last-child)::after',
      ),
      array(

      ),
    );

    $this->end_controls_section();

  }//end register controls



  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();
    $args = array(
      'menu' => $settings['eafree_simple_menu_choose_menu'],
      'menu_class' => 'eafree_simple_menu',
      'menu_id' => 'eafree_simple_menu_' . $id,
      'container' => 'nav',
      'container_class' => 'eafree_simple_menu_nav ' .
                           'eafree_simple_menu_nav_' . $id
    );
    wp_nav_menu( $args );
    ?>
    <?php if( \Elementor\Plugin::$instance->editor->is_edit_mode() ): ?>
      <script type="text/javascript">

      jQuery(document).ready(function($){
        <?php
        EAFREE_Inline_JS::elementary_addons_simple_menu_js( '.eafree_simple_menu_nav_' . $id );
        ?>
      });

      </script>
    <?php endif; ?>
    <?php
    $GLOBALS['elementary_addons_simple_menu_count'] += 1;
  }// end render
}
