<?php

namespace ElementaryAddons\Widgets;

use ElementaryAddons\Utils\EAFREE_Controls_Groups;
use ElementaryAddons\EAFREE_Inline_JS;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Core\DynamicTags\Tag;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Icons_Manager;

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class EAFREE_Vertical_Accordion extends Widget_Base{

  public function get_name(){
    return 'eafree_vertical_accordion';
  }

  public function get_title(){
    return esc_html__('Vertical Accordion', 'elementary-addons');
  }

  public function get_icon(){
    return 'eafree-icon eafree-icon-vertical-accordion'; // eicon-site-logo
  }

  public function get_categories(){
    return ['eafree-widgets'];
  }

  public function get_group() {
    return ['posts'];
  }

  protected function register_controls(){

    $this->start_controls_section(
      'eafree_vertical_accordion_settings_general',
      [
        'label' => 'General',
      ]
    );

    $this->add_control(
      'eafree_vertical_accordion_refresh',
      [
        'type' => Controls_Manager::RAW_HTML,
        'raw' => '<button class="elementor-button elementor-button-success" onclick="elementor.reloadPreview();">Refresh</button>',
        'separator' => 'after'
      ]
    );

    $this->add_control(
      'eafree_vertical_accordion_tab_tag',
      [
        'label' => esc_html__( 'Tab Heading Tag', 'elementary-addons' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'h2',
        'options' => [
          'h1' => esc_html__( 'H1', 'elementary-addons' ),
          'h2' => esc_html__( 'H2', 'elementary-addons' ),
          'h3' => esc_html__( 'H3', 'elementary-addons' ),
          'h4' => esc_html__( 'H4', 'elementary-addons' ),
          'h5' => esc_html__( 'H5', 'elementary-addons' ),
          'h6' => esc_html__( 'H6', 'elementary-addons' ),
        ],
      ]
    );

    $this->add_control(
      'eafree_vertical_accordion_lazyload_video',
      [
        'label' => esc_html__( 'Lazyload Video', 'braft-elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'braft-elementary-addons' ),
        'label_off' => esc_html__( 'No', 'braft-elementary-addons' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'eafree_vertical_accordion_first_open',
      [
        'label' => esc_html__( 'Open First Tab', 'braft-elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'braft-elementary-addons' ),
        'label_off' => esc_html__( 'No', 'braft-elementary-addons' ),
        'return_value' => 'yes',
        'default' => '',
      ]
    );

    $this->end_controls_section();

    ////////////////////////////// TABS //////////////////////////////////////
    $this->start_controls_section(
      'eafree_vertical_accordion_tabs_settings',
      [
        'label' => 'Tabs',
      ]
    );

    $this->add_control(
      'eafree_vertical_accordion_tab_show_icon',
      [
        'label' => esc_html__( 'Show Icon', 'braft-elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Show', 'braft-elementary-addons' ),
        'label_off' => esc_html__( 'Hide', 'braft-elementary-addons' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_responsive_control(
      'eafree_vertical_accordion_tab_video_width',
      [
        'label' => esc_html__( 'Video Width', 'braft-elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px','%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 2000,
          ],
          '%' => [
            'min' => 0,
            'max' => 100,
          ],
        ],
        'default' => [
          'unit' => 'px',
          'size' => 640,
        ],
        // 'selectors' => [
        //   '{{WRAPPER}} ' => 'width: {{SIZE}}{{UNIT}};',
        // ],
      ]
    );

    $this->add_responsive_control(
      'eafree_vertical_accordion_tab_video_height',
      [
        'label' => esc_html__( 'Video Height', 'braft-elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 2000,
          ],
          '%' => [
            'min' => 0,
            'max' => 100,
          ],
        ],
        'default' => [
          'unit' => 'px',
          'size' => 440,
        ],
        // 'selectors' => [
        //   '{{WRAPPER}} ' => 'height: {{SIZE}}{{UNIT}};',
        // ],
      ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
      'eafree_vertical_accordion_tab_text',
      [
        'label' => esc_html__( 'Tab text', 'elementary-addons' ),
        'type' => Controls_Manager::TEXT,
        'default' => esc_html__( 'Some Tab', 'elementary-addons' ),
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_tab_icon',
      [
        'label' => esc_html__( 'Icon', 'braft-elementary-addons' ),
        'type' => Controls_Manager::ICONS,
        'skin' => 'inline',
        'label_block' => false,
        'default' => [
          'value' => 'fas fa-icons',
          'library' => 'fa-solid',
        ],
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_content_text',
      [
        'label' => esc_html__( 'Content', 'elementary-addons' ),
        'type' => \Elementor\Controls_Manager::WYSIWYG,
        'default' => esc_html__( 'Some content...', 'elementary-addons' ),
        'placeholder' => esc_html__( 'Type your content here', 'elementary-addons' ),
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_is_video',
      [
        'label' => esc_html__( 'Enable Video', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_video_source',
      [
        'label' => esc_html__( 'Video Source', 'elementary-addons' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          'youtube' => esc_html__( 'YouTube', 'elementary-addons' ),
          'vimeo' => esc_html__( 'Vimeo', 'elementary-addons' ),
          'dailymotion' => esc_html__( 'Dailymotion', 'elementary-addons' ),
          'uploaded' => esc_html__( 'uploaded', 'elementary-addons' ),
        ],
        'frontend_available' => true,
        'default' => 'youtube',
        'condition' => ['eafree_vertical_accordion_is_video' => 'yes'],
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_youtube_link',
      [
        'label' => esc_html__( 'Youtube Link', 'elementary-addons' ),
        'type' => Controls_Manager::TEXT,
        'placeholder' => esc_html__( 'YouTube Video URL', 'elementary-addons' ),
        'label_block' => true,
        'frontend_available' => true,
        'condition' => ['eafree_vertical_accordion_video_source' => 'youtube'],
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_vimeo_link',
      [
        'label' => esc_html__( 'Vimeo Link', 'elementary-addons' ),
        'type' => Controls_Manager::TEXT,
        'placeholder' => esc_html__( 'Vimeo Video URL', 'elementary-addons' ),
        'label_block' => true,
        'condition' => ['eafree_vertical_accordion_video_source' => 'vimeo'],
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_dailymotion_link',
      [
        'label' => esc_html__( 'Dailymotion Link', 'elementary-addons' ),
        'type' => Controls_Manager::TEXT,
        'placeholder' => esc_html__( 'Dailymotion Video URL', 'elementary-addons' ),
        'label_block' => true,
        'condition' => ['eafree_vertical_accordion_video_source' => 'dailymotion'],
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_is_external_url',
      [
        'label' => esc_html__( 'External URL', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'condition' => ['eafree_vertical_accordion_video_source' => 'uploaded'],
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_uploaded_url',
      [
        'label' => esc_html__( 'Choose Video File', 'elementary-addons' ),
        'type' => Controls_Manager::MEDIA,
        'dynamic' => [
          'active' => true,
        ],
        'media_type' => 'video',
        'condition' => [
          'eafree_vertical_accordion_video_source' => 'uploaded',
          'eafree_vertical_accordion_is_external_url' => '',
        ],
      ]
    );

    $repeater->add_control(
      'eafree_vertical_accordion_external_url',
      [
        'label' => esc_html__( 'Video URL', 'elementary-addons' ),
        'type' => Controls_Manager::URL,
        'autocomplete' => false,
        'options' => false,
        'label_block' => true,
        'show_label' => false,
        'dynamic' => [
          'active' => true,
        ],
        'media_type' => 'video',
        'placeholder' => esc_html__( 'Video URL', 'elementary-addons' ),
        'condition' => [
          'eafree_vertical_accordion_video_source' => 'uploaded',
          'eafree_vertical_accordion_is_external_url' => 'yes',
        ],
      ]
    );

    $this->add_control(
      'eafree_vertical_accordion_tabs_list',
      [
        'label' => __( 'Accordion Tabs', 'elementary-addons' ),
        'type' => Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'eafree_vertical_accordion_tab_text' => esc_html__( 'Tab #1', 'elementary-addons' ),
            'eafree_vertical_accordion_tab_icon' => 'fas fa-icons',
            'eafree_vertical_accordion_content_text' => esc_html__( 'Content #1...', 'elementary-addons' ),

          ],
          [
            'eafree_vertical_accordion_tab_text' => esc_html__( 'Tab #2', 'elementary-addons' ),
            'eafree_vertical_accordion_tab_icon' => 'fas fa-icons',
            'eafree_vertical_accordion_content_text' => esc_html__( 'Content #2...', 'elementary-addons' ),

          ],
          [
            'eafree_vertical_accordion_tab_text' => esc_html__( 'Tab #3', 'elementary-addons' ),
            'eafree_vertical_accordion_tab_icon' => 'fas fa-icons',
            'eafree_vertical_accordion_content_text' => esc_html__( 'Content #3...', 'elementary-addons' ),

          ],

        ],
        'title_field' => '{{{ eafree_vertical_accordion_tab_text }}}',
      ]
    );

    $this->end_controls_section();

    ////////////////////////// STYLE GENERAL ////////////////////////////////
    $this->start_controls_section(
      'eafree_vertical_accordion_style_general',
      [
        'label' => esc_html__( 'General', 'elementary-addons' ),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    EAFREE_Controls_Groups::get_block_style_controls(
      $this,
      'eafree_vertical_accordion_ul',
      array(
        '{{WRAPPER}} .eafree_vertical_accordion',
      ),
    );

    $this->end_controls_section();


    ////////////////////////// TAB STYLE ////////////////////////////////
    $this->start_controls_section(
      'eafree_vertical_accordion_tab_style',
      [
        'label' => esc_html__( 'Tab', 'elementary-addons' ),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'eafree_vertical_accordion_tab_icon_color',
      [
        'label'  => esc_html__( 'Icon Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '#3a3a3a',
        'selectors' => [
          '{{WRAPPER}} .eafree_vertical_accordion .tab i' => 'color: {{VALUE}}',
          '{{WRAPPER}} .eafree_vertical_accordion .tab svg' => 'fill: {{VALUE}}',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_vertical_accordion_tab_icon_size',
      [
        'label' => esc_html__( 'Top Margin', 'elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 1,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 24,
          'unit' => 'px',
        ],
        'selectors' => [
          '{{WRAPPER}} .eafree_vertical_accordion .tab i' => 'font-size: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .eafree_vertical_accordion .tab svg' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    EAFREE_Controls_Groups::get_block_text_style_controls(
      $this,
      'eafree_vertical_accordion_tab',
      array(
        '{{WRAPPER}} .eafree_vertical_accordion .tab',
      ),
      array(
        'margin',
      ),
    );

    $this->end_controls_section();


    ////////////////////////// CONTENT STYLE ////////////////////////////////
    $this->start_controls_section(
      'eafree_vertical_accordion_content_style',
      [
        'label' => esc_html__( 'Content', 'elementary-addons' ),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    EAFREE_Controls_Groups::get_block_text_style_controls(
      $this,
      'eafree_vertical_accordion_content',
      array(
        '{{WRAPPER}} .eafree_vertical_accordion .content',
      ),
      array(
        'margin',
      ),
    );

    EAFREE_Controls_Groups::get_button_style_controls(
      $this,
      'eafree_vertical_accordion_content_link',
      array(
        '{{WRAPPER}} .eafree_vertical_accordion .content a',
      ),
    );

    $this->end_controls_section();

    ////////////////////////// VIDEO STYLE ////////////////////////////////
    $this->start_controls_section(
      'eafree_vertical_accordion_video_style',
      [
        'label' => esc_html__( 'Video container', 'elementary-addons' ),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    EAFREE_Controls_Groups::get_block_style_controls(
      $this,
      'eafree_vertical_accordion_video',
      array(
        '{{WRAPPER}} .eafree_vertical_accordion .content .video',
      ),
      array(

      ),
    );

    $this->end_controls_section();

  }//end register controls



  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();
    $tabs = $settings['eafree_vertical_accordion_tabs_list'];
    $v_width = $settings['eafree_vertical_accordion_tab_video_width']['size'] . $settings['eafree_vertical_accordion_tab_video_width']['unit'];
    $v_height = $settings['eafree_vertical_accordion_tab_video_height']['size'] . $settings['eafree_vertical_accordion_tab_video_height']['unit'];
    $lazyload_video = $settings['eafree_vertical_accordion_lazyload_video'];
    ?>
    <ul class="eafree_vertical_accordion eafree_vertical_accordion_<?php echo esc_attr( $id ); ?>">
      <?php for ( $i = 0; $i < count( $tabs ); $i++ ): ?>
        <?php
        if( $tabs[$i]['eafree_vertical_accordion_video_source'] === 'youtube' ){
          $video_url = $tabs[$i]['eafree_vertical_accordion_youtube_link'];
        }
        elseif( $tabs[$i]['eafree_vertical_accordion_video_source'] === 'dailymotion' ){
          $video_url = $tabs[$i]['eafree_vertical_accordion_dailymotion_link'];
        }
        elseif( $tabs[$i]['eafree_vertical_accordion_video_source'] === 'vimeo' ){
          $video_url = $tabs[$i]['eafree_vertical_accordion_vimeo_link'];
        }
        elseif( $tabs[$i]['eafree_vertical_accordion_video_source'] === 'uploaded' ){
          if( $tabs[$i]['eafree_vertical_accordion_is_external_url'] === 'yes' ){
            $video_url = $tabs[$i]['eafree_vertical_accordion_external_url']['url'];
          }
          else{
            $video_url = $tabs[$i]['eafree_vertical_accordion_uploaded_url']['url'];
          }
        }
        $video_source = $tabs[$i]['eafree_vertical_accordion_video_source'];

        if( $video_source === 'youtube' ){
          $iframe .= '<iframe ' .
          'width="' . $video_width . '"' .
          'height="' . $video_height . '"' .
          'src="' . $video_url . '"' .
          'title="YouTube video player"' .
          'frameborder="0"' .
          'allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"' .
          'allowfullscreen' .
          '></iframe>';
        }
        else if( $video_source === 'dailymotion' ){
          $iframe .= '<div style="position:relative;padding-bottom:56.25%;height:0;overflow:hidden;">' .
            '<iframe' .
            'style="width:100%;height:100%;position:absolute;left:0px;top:0px;overflow:hidden"' .
            'frameborder="0"' .
            'type="text/html"' .
            'src="' . $video_url . '"' .
            'width="' . $video_width . '"' .
            'height="' . $video_height . '"' .
            'allowfullscreen' .
            'title="Dailymotion Video Player"' .
            'allow="autoplay"' .
            '>' .
          '</iframe>' .
        '</div>';
        }
        else if( $video_source === 'vimeo' ){
          $iframe .= '<iframe' .
          'src="' . $video_url . '"' .
          'width="' . $video_width . '"' .
          'height="' . $video_height . '"' .
          'frameborder="0"' .
          'allow="autoplay; fullscreen; picture-in-picture"' .
          'allowfullscreen' .
          '>' .
        '</iframe>';
        }
        else if( $video_source === 'uploaded' ){
          $iframe .= '<video' .
          'controls' .
          'src="' . $video_url . '"' .
          '>' .
        '</video>';
        }
        ?>
        <li>
          <<?php echo esc_attr( $settings['eafree_vertical_accordion_tab_tag'] ); ?>
          class="tab"
          data-is_video="<?php echo esc_attr( $tabs[$i]['eafree_vertical_accordion_is_video'] ); ?>"
          data-video_source="<?php echo esc_attr( $tabs[$i]['eafree_vertical_accordion_video_source'] ); ?>"
          data-video_width="<?php echo esc_attr( $v_width ); ?>"
          data-video_height="<?php echo esc_attr( $v_height ); ?>"
          data-video_url="<?php echo esc_attr( $video_url ); ?>"
          data-lazyload_video="<?php echo esc_attr( $lazyload_video ); ?>"
          >
          <?php
          if( $settings['eafree_vertical_accordion_tab_show_icon'] === 'yes' ){
            Icons_Manager::render_icon( $tabs[$i]['eafree_vertical_accordion_tab_icon'], [ 'aria-hidden' => 'true' ] );
          }
          ?>
          <?php echo esc_html__( $tabs[$i]['eafree_vertical_accordion_tab_text'], 'elementary-addons' ); ?>
          </<?php echo esc_attr( $settings['eafree_vertical_accordion_tab_tag'] ); ?>>
          <?php
          $first_display = ( $settings['eafree_vertical_accordion_first_open'] === 'yes' && $i === 0 ) ? '' : 'display:none;';
          ?>
          <div class="content" style="<?php echo esc_attr( $first_display ); ?>">
            <?php echo wp_kses( $tabs[$i]['eafree_vertical_accordion_content_text'], 'post' ); ?>
            <?php if( $tabs[$i]['eafree_vertical_accordion_is_video'] === 'yes' ): ?>
              <div class="video">

                <?php if ( $lazyload_video !== 'yes' ): ?>
                  <?php
                  if( $video_source === 'youtube' ){
                    ?>
                      <iframe
                      width="<?php echo esc_attr( $v_width ); ?>"
                      height="<?php echo esc_attr( $v_height ); ?>"
                      src="<?php echo esc_attr( $video_url ); ?>"
                      title="YouTube video player"
                      frameborder="0"
                      allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
                      allowfullscreen
                      >
                      </iframe>
                    <?php
                  }
                  else if( $video_source === 'dailymotion' ){
                    ?>
                      <div style="position:relative;padding-bottom:56.25%;height:0;overflow:hidden;">
                        <iframe
                        style="width:100%;height:100%;position:absolute;left:0px;top:0px;overflow:hidden"
                        frameborder="0"
                        type="text/html"
                        src="<?php echo esc_attr( $video_url ); ?>"
                        width="<?php echo esc_attr( $v_width ); ?>"
                        height="<?php echo esc_attr( $v_height ); ?>"
                        allowfullscreen
                        title="Dailymotion Video Player"
                        allow="autoplay"
                        >
                        </iframe>
                      </div>
                    <?php
                  }
                  else if( $video_source === 'vimeo' ){
                    ?>
                      <iframe
                      src="<?php echo esc_attr( $video_url ); ?>"
                      width="<?php echo esc_attr( $v_width ); ?>"
                      height="<?php echo esc_attr( $v_height ); ?>"
                      frameborder="0"
                      allow="autoplay; fullscreen; picture-in-picture"
                      allowfullscreen
                      >
                      </iframe>
                    <?php
                  }
                  else if( $video_source === 'uploaded' ){
                    ?>
                      <video
                      controls
                      src="<?php echo esc_attr( $video_url ); ?>"
                      >
                      </video>
                    <?php
                  }
                  ?>
                <?php endif; ?>
              </div>
            <?php endif; ?>
          </div>
        </li>
      <?php endfor; ?>
    </ul>
    <?php if( \Elementor\Plugin::$instance->editor->is_edit_mode() ): ?>
      <script type="text/javascript">

      jQuery(document).ready(function($){
        <?php
        EAFREE_Inline_JS::elementary_addons_vertical_accordion_js( '.eafree_vertical_accordion_' . $id );
        ?>
      });

      </script>
    <?php endif; ?>
    <?php
    $GLOBALS['elementary_addons_vertical_accordion_count'] += 1;
  }// end render
}
